summaryrefslogtreecommitdiffstats
path: root/tdecore
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-06-08 15:51:46 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-06-08 15:51:46 -0500
commit6ed1ea98db6b1b369e7561efcc2c666b810e5446 (patch)
tree69da6d265387965c04a9584547ec42d4d372717d /tdecore
parent09d01cacf80d21ad213e6520b35e7f06e9546a83 (diff)
downloadtdelibs-6ed1ea98db6b1b369e7561efcc2c666b810e5446.tar.gz
tdelibs-6ed1ea98db6b1b369e7561efcc2c666b810e5446.zip
Update XDG information in support of bug report 892.
Diffstat (limited to 'tdecore')
-rw-r--r--tdecore/README.kiosk2
-rw-r--r--tdecore/README.kstartupinfo24
-rw-r--r--tdecore/kconfigbackend.cpp2
-rw-r--r--tdecore/kdesktopfile.cpp8
-rw-r--r--tdecore/kuniqueapplication.h2
5 files changed, 19 insertions, 19 deletions
diff --git a/tdecore/README.kiosk b/tdecore/README.kiosk
index feeec7199..b1c573a3e 100644
--- a/tdecore/README.kiosk
+++ b/tdecore/README.kiosk
@@ -483,7 +483,7 @@ will be "locked down" and it will no longer be possible to select
* kcalc - By marking the kcalcrc config file as immutable, the "Configure" button
will not be shown
-Application .desktop files can have an additional field "X-KDE-AuthorizeAction".
+Application .desktop files can have an additional field "X-TDE-AuthorizeAction".
If this field is present the .desktop file is only considered if the action(s)
mentioned in this field has been authorized. If multiple actions are listed
they should be separated by commas (','). So if the .desktop file of an application
diff --git a/tdecore/README.kstartupinfo b/tdecore/README.kstartupinfo
index 7f1aec52d..496f75ecd 100644
--- a/tdecore/README.kstartupinfo
+++ b/tdecore/README.kstartupinfo
@@ -40,14 +40,14 @@ ASN is useful in this case, it shouldn't be sent e.g. for system processes ).
These following .desktop file entries affect ASN :
-X-KDE-StartupNotify=<bool>
+X-TDE-StartupNotify=<bool>
- if true, this app/service will get app startup notify
- if false, this app/service will _not_ get app startup notify
- if not set
- if it's service, it will _not_ get app startup notify
- if it's app, it will get app startup notify, but
- X-KDE-WMClass will be assumed to be "0" ( non-compliant )
-X-KDE-WMClass=<string>
+ X-TDE-WMClass will be assumed to be "0" ( non-compliant )
+X-TDE-WMClass=<string>
- if set, and it's different from "0" ( without quotes ), this
is the WMClass value for startup notification
- if it's "0" ( without quotes ), such app is considered non-compliant,
@@ -66,21 +66,21 @@ X-KDE-WMClass=<string>
app's binary file, in such case it doesn't need to be explicitly set )
MapNotify=<bool>
- this key is obsolete
- - true is equivalent to X-KDE-StartupNotify=true and no X-KDE-WMClass set
- - false is equivalent to X-KDE-StartupNotify=true and X-KDE-WMClass=0
+ - true is equivalent to X-TDE-StartupNotify=true and no X-TDE-WMClass set
+ - false is equivalent to X-TDE-StartupNotify=true and X-TDE-WMClass=0
- many .desktop files in KDE ( especially in tdebase/kappfinder )
seem to have MapNotify=false even though it's not needed, this
- needs to be checked and replaced by the needed X-KDE-* values,
- often just X-KDE-StartupNotify=true should be enough
+ needs to be checked and replaced by the needed X-TDE-* values,
+ often just X-TDE-StartupNotify=true should be enough
The best way to check if the entries are set correctly is to start
the application and switch to other desktop. If the startup notification
disappears and the application appears on the desktop on which it was
-started, it's correct ( with X-KDE-WMClass=0, the start-on-desktop
+started, it's correct ( with X-TDE-WMClass=0, the start-on-desktop
feature may not work ).
- Ideally, every .desktop file should have X-KDE-StartupNotify set to the correct
-value, and for apps which need it also X-KDE-WMClass should be set. This
+ Ideally, every .desktop file should have X-TDE-StartupNotify set to the correct
+value, and for apps which need it also X-TDE-WMClass should be set. This
sometimes gives slightly better behavior than when these entries are not set.
@@ -165,9 +165,9 @@ doesn't have even the _NET_WM_PID property, WM_CLASS property is used
then. It's usually set to two strings, and at least one of them is
usually the binary name of the application, so it's converted
to lowercase and compared. For applications, where such comparison
-would fail, the X-KDE-WMClass .desktop file entry should be set
+would fail, the X-TDE-WMClass .desktop file entry should be set
to the correct WMClass value ( e.g. for XEmacs, the binary name
-is 'xemacs', but WM_CLASS is 'emacs', 'Emacs', so its X-KDE-WMClass
+is 'xemacs', but WM_CLASS is 'emacs', 'Emacs', so its X-TDE-WMClass
in its .desktop file should be set to 'emacs' - the case doesn't
matter ).
The ASN identification string must be a unique string for every ASN.
diff --git a/tdecore/kconfigbackend.cpp b/tdecore/kconfigbackend.cpp
index 4ad0e5fb2..efb2a20a9 100644
--- a/tdecore/kconfigbackend.cpp
+++ b/tdecore/kconfigbackend.cpp
@@ -753,7 +753,7 @@ tqWarning("SIGBUS while reading %s", rFile.name().latin1());
translateKey(locale, aCurrentGroup, TQCString("GenericName"));
translateKey(locale, aCurrentGroup, TQCString("Query"));
translateKey(locale, aCurrentGroup, TQCString("ExtraNames"));
- translateKey(locale, aCurrentGroup, TQCString("X-KDE-Submenu"));
+ translateKey(locale, aCurrentGroup, TQCString("X-TDE-Submenu"));
}
}
diff --git a/tdecore/kuniqueapplication.h b/tdecore/kuniqueapplication.h
index 973837850..b4ad50129 100644
--- a/tdecore/kuniqueapplication.h
+++ b/tdecore/kuniqueapplication.h
@@ -40,7 +40,7 @@ class KUniqueApplicationPrivate;
*
* If your application is used to open files, it should also support the --tempfile
* option (see KCmdLineArgs::addTempFileOption()), to delete tempfiles after use.
- * Add X-KDE-HasTempFileOption=true to the .desktop file to indicate this.
+ * Add X-TDE-HasTempFileOption=true to the .desktop file to indicate this.
*
* @see KApplication DCOPObject
* @author Preston Brown <pbrown@kde.org>
diff --git a/tdecore/kdesktopfile.cpp b/tdecore/kdesktopfile.cpp
index ac7fd250c..02dfb1d5f 100644
--- a/tdecore/kdesktopfile.cpp
+++ b/tdecore/kdesktopfile.cpp
@@ -272,7 +272,7 @@ bool KDesktopFile::hasDeviceType() const
bool KDesktopFile::tryExec() const
{
// Test for TryExec and "X-KDE-AuthorizeAction"
TQString te = readPathEntry("TryExec");
if (!te.isEmpty()) {
@@ -299,7 +299,7 @@ bool KDesktopFile::tryExec() const
return false;
}
}
- TQStringList list = readListEntry("X-KDE-AuthorizeAction");
+ TQStringList list = readListEntry("X-TDE-AuthorizeAction");
if (kapp && !list.isEmpty())
{
for(TQStringList::ConstIterator it = list.begin();
@@ -312,10 +312,10 @@ bool KDesktopFile::tryExec() const
}
// See also KService::username()
- bool su = readBoolEntry("X-KDE-SubstituteUID");
+ bool su = readBoolEntry("X-TDE-SubstituteUID");
if (su)
{
- TQString user = readEntry("X-KDE-Username");
+ TQString user = readEntry("X-TDE-Username");
if (user.isEmpty())
user = ::getenv("ADMIN_ACCOUNT");
if (user.isEmpty())
@@ -272,7 +272,7 @@ bool KDesktopFile::hasDeviceType() const
bool KDesktopFile::tryExec() const
{
- // Test for TryExec and "X-KDE-AuthorizeAction"
+ // Test for TryExec and "X-TDE-AuthorizeAction"
TQString te = readPathEntry("TryExec");
if (!te.isEmpty()) {